Documentation.addTranslations({
    "locale": "cy",
    "messages": {
        "%(filename)s &#8212; %(docstitle)s": "",
        "&#169; <a href=\"%(path)s\">Copyright</a> %(copyright)s.": "",
        "&#169; Copyright %(copyright)s.": "",
        ", in ": ", yn ",
        "About these documents": "Yngl\u0177n \u00e2'r dogfennau hyn",
        "Automatically generated list of changes in version %(version)s": "Rhestr o newidiadau yn fersiwn %(version)s wedi'i cynhyrchu'n awtomatig",
        "C API changes": "Newidiadau i'r C-API",
        "Changes in Version %(version)s &#8212; %(docstitle)s": "",
        "Collapse sidebar": "Cyfangu'r bar ochr",
        "Complete Table of Contents": "Tabl Cynnwys Llawn",
        "Contents": "Cynnwys",
        "Copyright": "Hawlfraint",
        "Created using <a href=\"https://www.sphinx-doc.org/\">Sphinx</a> %(sphinx_version)s.": "",
        "Expand sidebar": "Ehangu'r bar ochr",
        "Full index on one page": "Indecs llawn ar un tudalen",
        "General Index": "Indecs cyffredinol",
        "Global Module Index": "Indecs Modiwl Byd-Eang",
        "Go": "Ewch",
        "Hide Search Matches": "Cuddio Canlyniadau Chwilio",
        "Index": "Indecs",
        "Index &ndash; %(key)s": "Indecs &ndash; %(key)s",
        "Index pages by letter": "Indecs tudalennau gan lythyren",
        "Indices and tables:": "Indecsau a tablau:",
        "Last updated on %(last_updated)s.": "Diweddarwyd yn ddiwethaf ar %(last_updated)s.",
        "Library changes": "Newidiadau i'r llyfrgell",
        "Navigation": "Llywio",
        "Next topic": "Pwnc nesaf",
        "Other changes": "Newidiadau arall",
        "Overview": "Trosolwg",
        "Please activate JavaScript to enable the search\n    functionality.": "Trwoch JavaScript ymlaen i alluogi'r chwilio.",
        "Preparing search...": "Paratoi chwilio...",
        "Previous topic": "Pwnc blaenorol",
        "Quick search": "Chwilio cyflym",
        "Search": "Chwilio",
        "Search Page": "Tudalen Chwilio",
        "Search Results": "Canlyniadau chwilio",
        "Search finished, found ${resultCount} page(s) matching the search query.": "",
        "Search within %(docstitle)s": "Chwilio o fewn %(docstitle)s",
        "Searching": "Yn chwilio",
        "Searching for multiple words only shows matches that contain\n    all words.": "",
        "Show Source": "Dangos Ffynhonell",
        "Table of Contents": "",
        "This Page": "Y Dudalen Hon",
        "Welcome! This is": "Croeso! Dyma",
        "Your search did not match any documents. Please make sure that all words are spelled correctly and that you've selected enough categories.": "Nid yw eich chwiliad yn cyfateb unrhyw ddogfennau. Gwnewch yn si\u0175r fod pob gair wedi'i sillafu'n gywir, ac eich bod wedi dewis digon o gategor\u00efau.",
        "all functions, classes, terms": "holl ffwythiannau, dosbarthau a thermau",
        "can be huge": "gall fod yn enfawr",
        "last updated": "diweddarwyd yn ddiwethaf",
        "lists all sections and subsections": "rhestru holl adrannau ac isadrannau",
        "next chapter": "pennod nesaf",
        "previous chapter": "pennod blaenorol",
        "quick access to all modules": "mynediad cloi i bob modiwl",
        "search": "chwilio",
        "search this documentation": "chwiliwch y ddogfennaeth",
        "the documentation for": "y dogfennaeth am"
    },
    "plural_expr": "(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3"
});