Documentation.addTranslations({
    "locale": "nl",
    "messages": {
        "%(filename)s &#8212; %(docstitle)s": "%(filename)s &#8212; %(docstitle)s",
        "&#169; <a href=\"%(path)s\">Copyright</a> %(copyright)s.": "&#169; <a href=\"%(path)s\">Copyright</a> %(copyright)s.",
        "&#169; Copyright %(copyright)s.": "&#169; Copyright %(copyright)s.",
        ", in ": ", in",
        "About these documents": "Over deze documenten",
        "Automatically generated list of changes in version %(version)s": "Automatisch gegenereerde lijst van veranderingen in versie %(version)s",
        "C API changes": "Veranderingen in de C-API",
        "Changes in Version %(version)s &#8212; %(docstitle)s": "Wijzigingen in Versie %(version)s &#8212; %(docstitle)s",
        "Collapse sidebar": "Zijpaneel inklappen",
        "Complete Table of Contents": "Volledige inhoudsopgave",
        "Contents": "Inhoudsopgave",
        "Copyright": "Copyright",
        "Created using <a href=\"https://www.sphinx-doc.org/\">Sphinx</a> %(sphinx_version)s.": "",
        "Expand sidebar": "Zijpaneel uitklappen",
        "Full index on one page": "Volledige index op \u00e9\u00e9n pagina",
        "General Index": "Algemene index",
        "Global Module Index": "Globale Module-index",
        "Go": "Zoek",
        "Hide Search Matches": "Zoekresultaten verbergen",
        "Index": "Index",
        "Index &ndash; %(key)s": "Index &ndash; %(key)s",
        "Index pages by letter": "Index pagineerd per letter",
        "Indices and tables:": "Indices en tabellen:",
        "Last updated on %(last_updated)s.": "Laatste aanpassing op %(last_updated)s.",
        "Library changes": "Veranderingen in de bibliotheek",
        "Navigation": "Navigatie",
        "Next topic": "Volgend onderwerp",
        "Other changes": "Andere veranderingen",
        "Overview": "Overzicht",
        "Please activate JavaScript to enable the search\n    functionality.": "Activeer JavaSscript om de zoekfunctionaliteit in te schakelen.",
        "Preparing search...": "Zoeken aan het voorbereiden...",
        "Previous topic": "Vorig onderwerp",
        "Quick search": "Snel zoeken",
        "Search": "Zoeken",
        "Search Page": "Zoekpagina",
        "Search Results": "Zoekresultaten",
        "Search finished, found ${resultCount} page(s) matching the search query.": "",
        "Search within %(docstitle)s": "Zoeken in %(docstitle)s",
        "Searching": "Bezig met zoeken",
        "Searching for multiple words only shows matches that contain\n    all words.": "",
        "Show Source": "Broncode weergeven",
        "Table of Contents": "",
        "This Page": "Deze pagina",
        "Welcome! This is": "Welkom! Dit is",
        "Your search did not match any documents. Please make sure that all words are spelled correctly and that you've selected enough categories.": "Uw zoekopdracht leverde geen resultaten op. Zorg ervoor dat alle woorden juist zijn gespeld en dat u voldoende categorie\u00ebn hebt geselecteerd.",
        "all functions, classes, terms": "alle functies, klasses en begrippen",
        "can be huge": "kan heel groot zijn",
        "last updated": "laatst bijgewerkt",
        "lists all sections and subsections": "geeft alle secties en subsecties weer",
        "next chapter": "volgend hoofdstuk",
        "previous chapter": "vorig hoofdstuk",
        "quick access to all modules": "sneltoegang naar alle modules",
        "search": "zoeken",
        "search this documentation": "zoeken in deze documentatie",
        "the documentation for": "de documentatie voor"
    },
    "plural_expr": "(n != 1)"
});