



pip check || exit 0
IF %ERRORLEVEL% NEQ 0 exit /B 1
sphinx-build --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
sphinx-quickstart --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
sphinx-apidoc --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
sphinx-autogen --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
